package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Mar 28, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Host string `json:"host" yaml:"host"`
Port int32 `json:"port" yaml:"port"`
User string `json:"user" yaml:"user"`
Password string `json:"password" yaml:"password"`
PrivatePath string `json:"private_path" yaml:"private_path"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.